@@ -15,17 +15,73 @@ import os
 import sys
 
 if hasattr(sys, "frozen"):
-    class BlackHole(object):
-        closed = True
-        softspace = 0
-        def write(self, data):
-            pass
-        def close(self):
-            pass
-        def flush(self):
-            pass
-    sys.stdout = BlackHole()
-    sys.stderr = BlackHole()
+    if sys.frozen == 'windows_exe':
+        # sys.stdin is invalid, should be None.  Fixes svn, git subrepos
+        sys.stdin = None
+
+        # py2exe blackholes stdout with a custom class to prevent random
+        # exceptions when writing to it, but doesn't provide the ``.buffer``
+        # attribute that mercurial.utils.procutil wants.  As of 0.11.1.0, it
+        # also doesn't return the number of bytes written, and therefore
+        # violates the interface contract.  For details, see:
+        # https://github.com/py2exe/py2exe/blob/af0e841bffcf9c64abce6204718fecad17a59506/py2exe/boot_common.py#L3
+        #
+        # TODO: upstream write() return value and PROGRAMDATA usage in py2exe,
+        #  and then most or all of this can go away.
+        sys.stdout = open(os.devnull, "w")
+
+        # py2exe writes its redirected stderr log file next to the executable
+        # (so typically in %PROGRAMFILES%), but UAC blocks that when it is
+        # enabled.  Replacing stderr with our own log file to an always
+        # writeable area prevents that, fixes the missing write() return value,
+        # and provides the `.buffer` attribute that procutil assumes is present.
+        program_data = os.environ.get("PROGRAMDATA")
+
+        if program_data is not None:
+            import atexit, ctypes
+
+            dir_name = os.path.join(program_data, "TortoiseHg")
+            log_name = os.path.join(
+                dir_name,
+                os.path.splitext(
+                    os.path.basename(sys.executable)
+                )[0] + '.log'
+            )
+
+            try:
+                os.makedirs(dir_name, exist_ok=True)
+                sys.stderr = open(log_name, 'a', buffering=1)
+            except Exception as details:
+                sys.stderr = sys.stdout  # blackhole messages
+                ctypes.windll.user32.MessageBoxW(
+                    0,
+                    "The logfile '%s' could not be opened:\n %s" % (
+                        log_name, details,
+                    ),
+                    "Errors in %r" % os.path.basename(sys.executable),
+                    0
+                )
+            else:
+                orig_size = sys.stderr.seek(0, os.SEEK_END)
+
+                def exit_check():
+                    log_size = sys.stderr.tell()
+
+                    if orig_size != log_size:
+                        ctypes.windll.user32.MessageBoxW(
+                            0,
+                            "See the logfile '%s' for details" % log_name,
+                            "Errors in %r" % os.path.basename(sys.executable),
+                            0,
+                        )
+
+                atexit.register(exit_check)
+        else:
+            # py2exe messages come through sys.stderr; mercurial.ui.error()
+            # messages come through sys.stderr.buffer.  Drop everything for the
+            # *w.exe executable if the log file cannot be created, in order to
+            # prevent various issues mentioned above.
+            sys.stderr = sys.stdout
 
 import errno
 import time
