@@ -5,7 +5,7 @@ import inspect
 from tortoisehg.util import hglib, pipeui
 
 def test_same_argspec(f, g):
-    fa, ga = inspect.getargspec(f), inspect.getargspec(g)
+    fa, ga = inspect.getfullargspec(f), inspect.getfullargspec(g)
     assert fa == ga, '%s != %s' % (inspect.formatargspec(*fa),
                                    inspect.formatargspec(*ga))
 
