@@ -6,15 +6,13 @@
 # Copyright 2010 Johan Samyn <johan.samyn@gmail.com>
 #
 # This software may be used and distributed according to the terms of the
-# GNU General Public License version 2, incorporated herein by reference.
+# GNU General Public License version 2 or any later version.
 """
 TortoiseHg About dialog - PyQt4 version
 """
 
 from __future__ import absolute_import
 
-import platform
-import re
 import sys
 
 from .qtcore import (
@@ -23,7 +21,6 @@ from .qtcore import (
     QSize,
     QT_VERSION_STR,
     QTimer,
-    QUrl,
     Qt,
     pyqtSlot,
 )
@@ -37,14 +34,6 @@ from .qtgui import (
     QPlainTextEdit,
     QVBoxLayout,
 )
-from .qtnetwork import (
-    QNetworkAccessManager,
-    QNetworkRequest,
-)
-
-from mercurial import (
-    pycompat,
-)
 
 from ..util import (
     hglib,
@@ -52,7 +41,10 @@ from ..util import (
     version,
 )
 from ..util.i18n import _
-from . import qtlib
+from . import (
+    qtlib,
+    updatecheck,
+)
 
 class AboutDialog(QDialog):
     """Dialog for showing info about TortoiseHg"""
@@ -62,7 +54,7 @@ class AboutDialog(QDialog):
 
         self.setWindowIcon(qtlib.geticon('thg'))
         self.setWindowTitle(_('About'))
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
 
         self.vbox = QVBoxLayout()
         self.vbox.setSpacing(8)
@@ -70,33 +62,33 @@ class AboutDialog(QDialog):
         self.logo_lbl = QLabel()
         self.logo_lbl.setMinimumSize(QSize(92, 50))
         self.logo_lbl.setScaledContents(False)
-        self.logo_lbl.setAlignment(Qt.AlignCenter)
+        self.logo_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.logo_lbl.setPixmap(QPixmap(qtlib.iconpath('thg_logo_92x50.png')))
         self.vbox.addWidget(self.logo_lbl)
 
         self.name_version_libs_lbl = QLabel()
         self.name_version_libs_lbl.setText(' ')
-        self.name_version_libs_lbl.setAlignment(Qt.AlignCenter)
+        self.name_version_libs_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.name_version_libs_lbl.setTextInteractionFlags(
-                Qt.TextSelectableByMouse)
+                Qt.TextInteractionFlag.TextSelectableByMouse)
         self.vbox.addWidget(self.name_version_libs_lbl)
         self.getVersionInfo()
 
         self.copyright_lbl = QLabel()
-        self.copyright_lbl.setAlignment(Qt.AlignCenter)
+        self.copyright_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.copyright_lbl.setText('\n'
-                + _('Copyright 2008-2020 Steve Borho and others'))
+                + _('Copyright 2008-2023 Steve Borho and others'))
         self.vbox.addWidget(self.copyright_lbl)
         self.courtesy_lbl = QLabel()
-        self.courtesy_lbl.setAlignment(Qt.AlignCenter)
+        self.courtesy_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.courtesy_lbl.setText(
               _('Several icons are courtesy of the TortoiseSVN and Tango projects') + '\n')
         self.vbox.addWidget(self.courtesy_lbl)
 
         self.download_url_lbl = QLabel()
         self.download_url_lbl.setMouseTracking(True)
-        self.download_url_lbl.setAlignment(Qt.AlignCenter)
-        self.download_url_lbl.setTextInteractionFlags(Qt.LinksAccessibleByMouse)
+        self.download_url_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
+        self.download_url_lbl.setTextInteractionFlags(Qt.TextInteractionFlag.LinksAccessibleByMouse)
         self.download_url_lbl.setOpenExternalLinks(True)
         self.download_url_lbl.setText('<a href=%s>%s</a>' %
                                       ('https://tortoisehg.bitbucket.io',
@@ -107,7 +99,7 @@ class AboutDialog(QDialog):
         self.vbox.addWidget(QLabel())
 
         self.hosting_lbl = QLabel()
-        self.hosting_lbl.setAlignment(Qt.AlignCenter)
+        self.hosting_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.hosting_lbl.setText(
             _('Hosting donated by %s and %s') % (
                 '<a href=https://clever-cloud.com>Clever Cloud</a>',
@@ -116,7 +108,7 @@ class AboutDialog(QDialog):
         )
         self.hosting_lbl.setMouseTracking(True)
         self.hosting_lbl.setTextInteractionFlags(
-            Qt.LinksAccessibleByMouse
+            Qt.TextInteractionFlag.LinksAccessibleByMouse
         )
         self.hosting_lbl.setOpenExternalLinks(True)
         self.vbox.addWidget(self.hosting_lbl)
@@ -127,21 +119,22 @@ class AboutDialog(QDialog):
 
         bbox = QDialogButtonBox(self)
         self.license_btn = bbox.addButton(_('&License'),
-                                          QDialogButtonBox.ResetRole)
+                                          QDialogButtonBox.ButtonRole.ResetRole)
         self.license_btn.setAutoDefault(False)
         self.license_btn.clicked.connect(self.showLicense)
-        self.close_btn = bbox.addButton(QDialogButtonBox.Close)
+        self.close_btn = bbox.addButton(QDialogButtonBox.StandardButton.Close)
         self.close_btn.setDefault(True)
         self.close_btn.clicked.connect(self.close)
         self.vbox.addWidget(bbox)
 
         self.setLayout(self.vbox)
-        self.layout().setSizeConstraint(QLayout.SetFixedSize)
+        self.layout().setSizeConstraint(QLayout.SizeConstraint.SetFixedSize)
         self._readsettings()
 
         # Spawn it later, so that the dialog gets visible quickly.
-        QTimer.singleShot(1000, self.getUpdateInfo)
-        self._newverreply = None
+        self._updatechecker = updatecheck.Checker()
+        self._updatechecker.updateAvailable.connect(self.updateAvailable)
+        QTimer.singleShot(1000, self._updatechecker.query)
 
     def getVersionInfo(self):
         def make_version(tuple):
@@ -159,103 +152,19 @@ class AboutDialog(QDialog):
         nvl = ''.join([name, thgv, libv])
         self.name_version_libs_lbl.setText(nvl)
 
-    @pyqtSlot()
-    def getUpdateInfo(self):
-        verurl = 'https://www.mercurial-scm.org/release/tortoisehg/latest.dat'
-        # If we use QNetworkAcessManager elsewhere, it should be shared
-        # through the application.
-        self._netmanager = QNetworkAccessManager(self)
-        self._newverreply = self._netmanager.get(QNetworkRequest(QUrl(verurl)))
-        self._newverreply.finished.connect(self.uFinished)
-
-    @pyqtSlot()
-    def uFinished(self):
-        newver = (0,0,0)
-
-        try:
-            data = self._newverreply.readAll().data()
-        finally:
-            self._newverreply.close()
-            self._newverreply = None
-
-        # Simulate a User-Agent string for platforms with an entry in the file.
-        # https://developers.whatismybrowser.com/useragents/explore/operating_system_name
-        useragent = "unknown"
-        if sys.platform == 'win32':
-            from win32process import (  # pytype: disable=import-error
-                IsWow64Process as IsX64
-            )
-            if IsX64():
-                useragent = "Windows WOW64"
-            else:
-                import struct
-                width = struct.calcsize("P") * 8
-                useragent = width == 64 and 'Windows x64' or 'Windows'
-        elif sys.platform == 'darwin':
-            # Mac packages will be universal binaries, but try to include the
-            # architecture so that older architectures can eventually be
-            # dropped from the current installer, and the last of the older
-            # architecture offered independently.
-            useragent = "Macintosh"
-            arch = platform.processor()
-            if arch == 'i386':
-                useragent += "; Intel"
-
-        candidates = {}
-
-        # Extra check to ensure the regex returned from the server is safe
-        # before using it.
-        def _check_regex(p):
-            # Clear any simple groups.  Example: ``.*Windows.*(WOW|x)64.*``
-            p = re.sub(r"\([0-9A-Za-z|]+\)", "", p)
-
-            # Now the regex should be a simple alphanumeric or wildcards
-            return re.match("^[A-Za-z0-9.*]+$", p)
-
-        # https://www.mercurial-scm.org/wiki/Packaging#Version_information_protocol
-        # priority \t version \t user-agent-regex \t download url \t desc
-        for line in pycompat.sysstr(data).splitlines():
-            try:
-                parts = line.strip().split("\t")
-                pattern = parts[2]
-
-                if not _check_regex(pattern):
-                    print("Ignoring upgrade pattern %s" % pattern)
-                    continue
-
-                if not re.match(pattern, useragent):
-                    continue
-
-                prio = int(parts[0].strip())
-                candidates[prio] = (parts[1].strip(), parts[3].strip())
-            except (IndexError, ValueError):
-                pass
-
-        if not candidates:
-            return
-
-        prio = [p for p in sorted(candidates.keys())][0]
-        newverstr, upgradeurl = candidates[prio]
-
-        try:
-            newver = tuple([int(p) for p in newverstr.split('.')])
-            thgv = version.package_version()
-            curver = tuple([int(p) for p in thgv.split('.')])
-        except ValueError:
-            curver = (0,0,0)
-        if newver > curver:
-            url_lbl = _('A new version of TortoiseHg (%s) '
-                        'is ready for download!') % newverstr
-            urldata = ('<a href=%s>%s</a>' % (upgradeurl, url_lbl))
-            self.download_url_lbl.setText(urldata)
+    @pyqtSlot(str, str)
+    def updateAvailable(self, newverstr, upgradeurl):
+        url_lbl = _('A new version of TortoiseHg (%s) '
+                    'is ready for download!') % newverstr
+        urldata = ('<a href=%s>%s</a>' % (upgradeurl, url_lbl))
+        self.download_url_lbl.setText(urldata)
 
     def showLicense(self):
         ld = LicenseDialog(self)
         ld.exec_()
 
     def closeEvent(self, event):
-        if self._newverreply:
-            self._newverreply.abort()
+        self._updatechecker.close()
         self._writesettings()
         super(AboutDialog, self).closeEvent(event)
 
@@ -275,13 +184,13 @@ class LicenseDialog(QDialog):
 
         self.setWindowIcon(qtlib.geticon('thg'))
         self.setWindowTitle(_('License'))
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.resize(700, 400)
 
         self.lic_txt = QPlainTextEdit()
         self.lic_txt.setFont(QFont('Monospace'))
         self.lic_txt.setTextInteractionFlags(
-                Qt.TextSelectableByKeyboard|Qt.TextSelectableByMouse)
+                Qt.TextInteractionFlag.TextSelectableByKeyboard|Qt.TextInteractionFlag.TextSelectableByMouse)
         try:
             with open(paths.get_license_path(), 'r') as fp:
                 lic = fp.read()
@@ -290,7 +199,7 @@ class LicenseDialog(QDialog):
             pass
 
         bbox = QDialogButtonBox(self)
-        self.close_btn = bbox.addButton(QDialogButtonBox.Close)
+        self.close_btn = bbox.addButton(QDialogButtonBox.StandardButton.Close)
         self.close_btn.clicked.connect(self.close)
 
         self.vbox = QVBoxLayout()
