@@ -30,6 +30,7 @@ from mercurial import (
     hg,
     node,
     phases,
+    pycompat,
     revset as revsetmod,
 )
 
@@ -265,7 +266,7 @@ def hashcolor(data, modulo=None):
     """
     if modulo is None:
         modulo = len(COLORS)
-    if isinstance(data, str):
+    if isinstance(data, (str, pycompat.unicode)):
         idx = sum([ord(c) for c in data])
     else: # Python 3 bytes
         idx = sum(data)
@@ -707,7 +708,8 @@ class ShallowFileDag(FileDag):
         path = self.path
 
         try:
-            dest = repo.ui.expandpath('default')
+            # TODO: switch to one of the urlutil.get_*path() functions
+            dest = repo.ui.expandpath(b'default')
             peer = hg.peer(repo, {}, dest)
         except error.RepoError:
             peer = None
@@ -716,7 +718,7 @@ class ShallowFileDag(FileDag):
         repoheads = set(repo.heads())
 
         # Get filelog heads from server and filter local heads with peer heads
-        if peer is not None and peer.capable('getflogheads'):
+        if peer is not None and peer.capable(b'getflogheads'):
             repoheads -= set(peer.heads())
             flogheads.update(set(peer.getflogheads(path)))
 
