@@ -57,7 +57,7 @@ except ImportError:
     config_nofork = None
 
 shortlicense = b'''
-Copyright (C) 2008-2022 Steve Borho <steve@borho.org> and others.
+Copyright (C) 2008-2023 Steve Borho <steve@borho.org> and others.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 '''
@@ -137,8 +137,8 @@ def dispatch(args, u=None):
         if b'--debugger' in args:
             pdb.set_trace()
         return _runcatch(u, args)
-    except error.ParseError as e:
-        qtapp.earlyExceptionMsgBox(hglib.tounicode(str(e)))
+    except error.ConfigError as e:
+        qtapp.earlyExceptionMsgBox(e)
     except SystemExit as e:
         return e.code
     except Exception as e:
